@@ -36,11 +36,8 @@
 
 #include <moveit/depth_image_octomap_updater/depth_image_octomap_updater.h>
 #include <moveit/occupancy_map_monitor/occupancy_map_monitor.h>
-#if __has_include(<tf2_geometry_msgs/tf2_geometry_msgs.hpp>)
+#include <cmath>
 #include <tf2_geometry_msgs/tf2_geometry_msgs.hpp>
-#else
-#include <tf2_geometry_msgs/tf2_geometry_msgs.h>
-#endif
 #include <tf2/LinearMath/Vector3.h>
 #include <tf2/LinearMath/Transform.h>
 #include <geometric_shapes/shape_operations.h>
@@ -48,7 +45,6 @@
 #include <stdint.h>
 
 #include <memory>
-#include <boost/bind.hpp>
 
 namespace occupancy_map_monitor
 {
@@ -97,7 +93,8 @@ bool DepthImageOctomapUpdater::setParams(const std::string& name_space)
         node_->get_parameter(name_space + ".max_update_rate", max_update_rate_) &&
         node_->get_parameter(name_space + ".skip_vertical_pixels", skip_vertical_pixels_) &&
         node_->get_parameter(name_space + ".skip_horizontal_pixels", skip_horizontal_pixels_) &&
-        node_->get_parameter(name_space + ".filtered_cloud_topic", filtered_cloud_topic_);
+        node_->get_parameter(name_space + ".filtered_cloud_topic", filtered_cloud_topic_) &&
+        node_->get_parameter(name_space + ".ns", ns_);
     return true;
   }
   catch (const rclcpp::exceptions::InvalidParameterTypeException& e)
@@ -125,32 +122,39 @@ bool DepthImageOctomapUpdater::initialize(const rclcpp::Node::SharedPtr& node)
   mesh_filter_->setShadowThreshold(shadow_threshold_);
   mesh_filter_->setPaddingOffset(padding_offset_);
   mesh_filter_->setPaddingScale(padding_scale_);
-  mesh_filter_->setTransformCallback(boost::bind(&DepthImageOctomapUpdater::getShapeTransform, this,
-                                                 boost::placeholders::_1, boost::placeholders::_2));
-
-  // init rclcpp time default value
-  last_update_time_ = node_->now();
+  mesh_filter_->setTransformCallback(
+      [this](mesh_filter::MeshHandle mesh, Eigen::Isometry3d& tf) { return getShapeTransform(mesh, tf); });
 
   return true;
 }
 
 void DepthImageOctomapUpdater::start()
 {
-  rmw_qos_profile_t custom_qos = rmw_qos_profile_system_default;
   pub_model_depth_image_ = model_depth_transport_->advertiseCamera("model_depth", 1);
 
+  std::string prefix = "";
+  if (!ns_.empty())
+    prefix = ns_ + "/";
+
+  pub_model_depth_image_ = model_depth_transport_->advertiseCamera(prefix + "model_depth", 1);
   if (!filtered_cloud_topic_.empty())
-    pub_filtered_depth_image_ = filtered_depth_transport_->advertiseCamera(filtered_cloud_topic_, 1);
+  {
+    pub_filtered_depth_image_ = filtered_depth_transport_->advertiseCamera(prefix + filtered_cloud_topic_, 1);
+  }
   else
-    pub_filtered_depth_image_ = filtered_depth_transport_->advertiseCamera("filtered_depth", 1);
+  {
+    pub_filtered_depth_image_ = filtered_depth_transport_->advertiseCamera(prefix + "filtered_depth", 1);
+  }
 
-  pub_filtered_label_image_ = filtered_label_transport_->advertiseCamera("filtered_label", 1);
+  pub_filtered_label_image_ = filtered_label_transport_->advertiseCamera(prefix + "filtered_label", 1);
 
-  sub_depth_image_ =
-      image_transport::create_camera_subscription(node_.get(), image_topic_,
-                                                  boost::bind(&DepthImageOctomapUpdater::depthImageCallback, this,
-                                                              boost::placeholders::_1, boost::placeholders::_2),
-                                                  "raw", custom_qos);
+  sub_depth_image_ = image_transport::create_camera_subscription(
+      node_.get(), image_topic_,
+      [this](const sensor_msgs::msg::Image::ConstSharedPtr& depth_msg,
+             const sensor_msgs::msg::CameraInfo::ConstSharedPtr& info_msg) {
+        return depthImageCallback(depth_msg, info_msg);
+      },
+      "raw", rmw_qos_profile_sensor_data);
 }
 
 void DepthImageOctomapUpdater::stop()
@@ -169,7 +173,9 @@ mesh_filter::MeshHandle DepthImageOctomapUpdater::excludeShape(const shapes::Sha
   if (mesh_filter_)
   {
     if (shape->type == shapes::MESH)
+    {
       h = mesh_filter_->addMesh(static_cast<const shapes::Mesh&>(*shape));
+    }
     else
     {
       std::unique_ptr<shapes::Mesh> m(shapes::createMeshFromShape(shape.get()));
@@ -225,7 +231,7 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
   if (max_update_rate_ > 0)
   {
     // ensure we are not updating the octomap representation too often
-    if (node_->now() - last_update_time_ <= rclcpp::Duration(std::chrono::duration<double>(1.0 / max_update_rate_)))
+    if (node_->now() - last_update_time_ <= rclcpp::Duration::from_seconds(1.0 / max_update_rate_))
       return;
     last_update_time_ = node_->now();
   }
@@ -237,16 +243,22 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
     {
       const double dt_start = (start - last_depth_callback_start_).seconds();
       if (image_callback_count_ < 2)
+      {
         average_callback_dt_ = dt_start;
+      }
       else
-        average_callback_dt_ =
-            ((image_callback_count_ - 1) * average_callback_dt_ + dt_start) / (double)image_callback_count_;
+      {
+        average_callback_dt_ = ((image_callback_count_ - 1) * average_callback_dt_ + dt_start) /
+                               static_cast<double>(image_callback_count_);
+      }
     }
   }
   else
+  {
     // every 1000 updates we reset the counter almost to the beginning (use 2 so we don't have so much of a ripple in
     // the measured average)
     image_callback_count_ = 2;
+  }
   last_depth_callback_start_ = start;
   ++image_callback_count_;
 
@@ -256,7 +268,9 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
   /* get transform for cloud into map frame */
   tf2::Stamped<tf2::Transform> map_h_sensor;
   if (monitor_->getMapFrame() == depth_msg->header.frame_id)
+  {
     map_h_sensor.setIdentity();
+  }
   else
   {
     if (tf_buffer_)
@@ -268,6 +282,7 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
       bool found = false;
       std::string err;
       for (int t = 0; t < nt; ++t)
+      {
         try
         {
           tf2::fromMsg(tf_buffer_->lookupTransform(monitor_->getMapFrame(), depth_msg->header.frame_id,
@@ -283,6 +298,7 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
           err = ex.what();
           std::this_thread::sleep_for(D.to_chrono<std::chrono::seconds>());
         }
+      }
       static const unsigned int MAX_TF_COUNTER = 1000;  // so we avoid int overflow
       if (found)
       {
@@ -298,13 +314,23 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
       {
         failed_tf_++;
         if (failed_tf_ > good_tf_)
+        {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
           RCLCPP_WARN_THROTTLE(LOGGER, *node_->get_clock(), 1000,
                                "More than half of the image messages discarded due to TF being unavailable (%u%%). "
                                "Transform error of sensor data: %s; quitting callback.",
                                (100 * failed_tf_) / (good_tf_ + failed_tf_), err.c_str());
+#pragma GCC diagnostic pop
+        }
         else
+        {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
           RCLCPP_DEBUG_THROTTLE(LOGGER, *node_->get_clock(), 1000,
                                 "Transform error of sensor data: %s; quitting callback", err.c_str());
+#pragma GCC diagnostic pop
+        }
         if (failed_tf_ > MAX_TF_COUNTER)
         {
           const unsigned int div = MAX_TF_COUNTER / 10;
@@ -322,7 +348,12 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
     return;
 
   if (depth_msg->is_bigendian && !HOST_IS_BIG_ENDIAN)
+  {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
     RCLCPP_ERROR_THROTTLE(LOGGER, *node_->get_clock(), 1000, "endian problem: received image data does not match host");
+#pragma GCC diagnostic pop
+  }
 
   const int w = depth_msg->width;
   const int h = depth_msg->height;
@@ -334,13 +365,18 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
 
   const bool is_u_short = depth_msg->encoding == sensor_msgs::image_encodings::TYPE_16UC1;
   if (is_u_short)
+  {
     mesh_filter_->filter(&depth_msg->data[0], GL_UNSIGNED_SHORT);
+  }
   else
   {
     if (depth_msg->encoding != sensor_msgs::image_encodings::TYPE_32FC1)
     {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
       RCLCPP_ERROR_THROTTLE(LOGGER, *node_->get_clock(), 1000, "Unexpected encoding type: '%s'. Ignoring input.",
                             depth_msg->encoding.c_str());
+#pragma GCC diagnostic pop
       return;
     }
     mesh_filter_->filter(&depth_msg->data[0], GL_FLOAT);
@@ -365,7 +401,7 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
     inv_fy_ = 1.0 / K4_;
 
     // if there are any NaNs, discard data
-    if (!(px == px && py == py && inv_fx_ == inv_fx_ && inv_fy_ == inv_fy_))
+    if (isnan(px) || isnan(py) || isnan(inv_fx_) || isnan(inv_fy_))
       return;
 
     // Pre-compute some constants
@@ -475,12 +511,13 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
       const uint16_t* input_row = reinterpret_cast<const uint16_t*>(&depth_msg->data[0]);
 
       for (int y = skip_vertical_pixels_; y < h_bound; ++y, labels_row += w, input_row += w)
+      {
         for (int x = skip_horizontal_pixels_; x < w_bound; ++x)
         {
           // not filtered
           if (labels_row[x] == mesh_filter::MeshFilterBase::BACKGROUND)
           {
-            float zz = (float)input_row[x] * 1e-3;  // scale from mm to m
+            float zz = static_cast<float>(input_row[x]) * 1e-3;  // scale from mm to m
             float yy = y_cache_[y] * zz;
             float xx = x_cache_[x] * zz;
             /* transform to map frame */
@@ -499,12 +536,14 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
             model_cells.insert(tree_->coordToKey(point_tf.getX(), point_tf.getY(), point_tf.getZ()));
           }
         }
+      }
     }
     else
     {
       const float* input_row = reinterpret_cast<const float*>(&depth_msg->data[0]);
 
       for (int y = skip_vertical_pixels_; y < h_bound; ++y, labels_row += w, input_row += w)
+      {
         for (int x = skip_horizontal_pixels_; x < w_bound; ++x)
         {
           if (labels_row[x] == mesh_filter::MeshFilterBase::BACKGROUND)
@@ -527,6 +566,7 @@ void DepthImageOctomapUpdater::depthImageCallback(const sensor_msgs::msg::Image:
             model_cells.insert(tree_->coordToKey(point_tf.getX(), point_tf.getY(), point_tf.getZ()));
           }
         }
+      }
     }
   }
   catch (...)
