@@ -34,24 +34,29 @@
 
 /* Author: Sachin Chitta */
 
-#include <rclcpp/rclcpp.hpp>
 #include <visualization_msgs/msg/marker_array.hpp>
 #include <geometry_msgs/msg/quaternion.hpp>
-
 // MoveIt
 #include <moveit/semantic_world/semantic_world.h>
 #include <geometric_shapes/shape_operations.h>
 #include <moveit_msgs/msg/planning_scene.hpp>
-
 // OpenCV
 #include <opencv2/imgproc/imgproc.hpp>
+#include <rclcpp/experimental/buffers/intra_process_buffer.hpp>
+#include <rclcpp/logger.hpp>
+#include <rclcpp/logging.hpp>
+#include <rclcpp/node.hpp>
+#include <rclcpp/publisher.hpp>
+#include <rclcpp/version.h>
+#if RCLCPP_VERSION_GTE(20, 0, 0)
+#include <rclcpp/event_handler.hpp>
+#else
+#include <rclcpp/qos_event.hpp>
+#endif
+#include <rclcpp/subscription.hpp>
 
 // Eigen
-#if __has_include(<tf2_eigen/tf2_eigen.hpp>)
 #include <tf2_eigen/tf2_eigen.hpp>
-#else
-#include <tf2_eigen/tf2_eigen.h>
-#endif
 #include <Eigen/Geometry>
 
 namespace moveit
@@ -60,13 +65,14 @@ namespace semantic_world
 {
 static const rclcpp::Logger LOGGER = rclcpp::get_logger("moveit.ros.perception.semantic_world");
 
-SemanticWorld::SemanticWorld(const rclcpp::Node::SharedPtr node,
+SemanticWorld::SemanticWorld(const rclcpp::Node::SharedPtr& node,
                              const planning_scene::PlanningSceneConstPtr& planning_scene)
   : planning_scene_(planning_scene), node_handle_(node)
 
 {
   table_subscriber_ = node_handle_->create_subscription<object_recognition_msgs::msg::TableArray>(
-      "table_array", 1, std::bind(&SemanticWorld::tableCallback, this, std::placeholders::_1));
+      "table_array", rclcpp::SystemDefaultsQoS(),
+      [this](const object_recognition_msgs::msg::TableArray::ConstSharedPtr& msg) { return tableCallback(msg); });
   visualization_publisher_ =
       node_handle_->create_publisher<visualization_msgs::msg::MarkerArray>("visualize_place", 20);
   collision_object_publisher_ =
@@ -330,13 +336,21 @@ SemanticWorld::generatePlacePoses(const object_recognition_msgs::msg::Table& tab
   for (std::size_t j = 1; j < table.convex_hull.size(); ++j)
   {
     if (table.convex_hull[j].x < x_min)
+    {
       x_min = table.convex_hull[j].x;
+    }
     else if (table.convex_hull[j].x > x_max)
+    {
       x_max = table.convex_hull[j].x;
+    }
     if (table.convex_hull[j].y < y_min)
+    {
       y_min = table.convex_hull[j].y;
+    }
     else if (table.convex_hull[j].y > y_max)
+    {
       y_max = table.convex_hull[j].y;
+    }
   }
   for (const geometry_msgs::msg::Point& vertex : table.convex_hull)
     table_contour.push_back(cv::Point((vertex.x - x_min) * scale_factor, (vertex.y - y_min) * scale_factor));
@@ -376,7 +390,8 @@ SemanticWorld::generatePlacePoses(const object_recognition_msgs::msg::Table& tab
         double result = cv::pointPolygonTest(contours[0], point2f, true);
         if (static_cast<int>(result) >= static_cast<int>(min_distance_from_edge * scale_factor))
         {
-          Eigen::Vector3d point((double)(point_x) / scale_factor + x_min, (double)(point_y) / scale_factor + y_min,
+          Eigen::Vector3d point(static_cast<double>(point_x) / scale_factor + x_min,
+                                static_cast<double>(point_y) / scale_factor + y_min,
                                 height_above_table + mm * delta_height);
           Eigen::Isometry3d pose;
           tf2::fromMsg(table.pose, pose);
@@ -406,13 +421,21 @@ bool SemanticWorld::isInsideTableContour(const geometry_msgs::msg::Pose& pose,
   for (std::size_t j = 1; j < table.convex_hull.size(); ++j)
   {
     if (table.convex_hull[j].x < x_min)
+    {
       x_min = table.convex_hull[j].x;
+    }
     else if (table.convex_hull[j].x > x_max)
+    {
       x_max = table.convex_hull[j].x;
+    }
     if (table.convex_hull[j].y < y_min)
+    {
       y_min = table.convex_hull[j].y;
+    }
     else if (table.convex_hull[j].y > y_max)
+    {
       y_max = table.convex_hull[j].y;
+    }
   }
   const int scale_factor = 100;
   std::vector<cv::Point2f> table_contour;
@@ -472,7 +495,7 @@ std::string SemanticWorld::findObjectTable(const geometry_msgs::msg::Pose& pose,
   return std::string();
 }
 
-void SemanticWorld::tableCallback(const object_recognition_msgs::msg::TableArray::SharedPtr msg)
+void SemanticWorld::tableCallback(const object_recognition_msgs::msg::TableArray::ConstSharedPtr& msg)
 {
   table_array_ = *msg;
   RCLCPP_INFO(LOGGER, "Table callback with %d tables", static_cast<int>(table_array_.tables.size()));
@@ -492,7 +515,7 @@ void SemanticWorld::transformTableArray(object_recognition_msgs::msg::TableArray
     std::string original_frame = table.header.frame_id;
     if (table.convex_hull.empty())
       continue;
-    RCLCPP_INFO_STREAM(LOGGER, "Original pose: " << table.pose.position.x << "," << table.pose.position.y << ","
+    RCLCPP_INFO_STREAM(LOGGER, "Original pose: " << table.pose.position.x << ',' << table.pose.position.y << ','
                                                  << table.pose.position.z);
     std::string error_text;
     const Eigen::Isometry3d& original_transform = planning_scene_->getFrameTransform(original_frame);
@@ -503,7 +526,7 @@ void SemanticWorld::transformTableArray(object_recognition_msgs::msg::TableArray
     table.header.frame_id = planning_scene_->getTransforms().getTargetFrame();
     RCLCPP_INFO_STREAM(LOGGER, "Successfully transformed table array from " << original_frame << "to "
                                                                             << table.header.frame_id);
-    RCLCPP_INFO_STREAM(LOGGER, "Transformed pose: " << table.pose.position.x << "," << table.pose.position.y << ","
+    RCLCPP_INFO_STREAM(LOGGER, "Transformed pose: " << table.pose.position.x << ',' << table.pose.position.y << ','
                                                     << table.pose.position.z);
   }
 }
@@ -625,10 +648,14 @@ shapes::Mesh* SemanticWorld::createSolidMeshFromPlanarPolygon(const shapes::Mesh
     Eigen::Vector3d triangle_normal = vec2.cross(vec1);
 
     if (triangle_normal.dot(normal) < 0.0)
+    {
       std::swap(solid->triangles[t_idx * 3 + 1], solid->triangles[t_idx * 3 + 2]);
+    }
     else
+    {
       std::swap(solid->triangles[(t_idx + polygon.triangle_count) * 3 + 1],
                 solid->triangles[(t_idx + polygon.triangle_count) * 3 + 2]);
+    }
   }
 
   for (unsigned v_idx = 0; v_idx < polygon.vertex_count; ++v_idx)
